@@ -3,7 +3,7 @@ from urllib.parse import quote
 
 
 class User(object):
-    '''This looks a little like the JupyterHub User object, but is not one.
+    """This looks a little like the JupyterHub User object, but is not one.
 
     It has the following attributes:
       name (str)
@@ -19,16 +19,16 @@ class User(object):
     The only place we substitute one of these for a JupyterHub User is in
     create_workflow.  We use the escaped_name and groups fields for that.
     (Groups is indirect via the quota manager.)
-    '''
+    """
 
     def __init__(self, *args, **kwargs):
-        self.name = kwargs.pop('name', None)
+        self.name = kwargs.pop("name", None)
         if self.name:
             self.escaped_name = quote(self.name)
-        self.namespace = kwargs.pop('namespace', None)
-        self.uid = kwargs.pop('uid', None)
-        self.access_token = kwargs.pop('access_token', None)
-        self.claims = kwargs.pop('claims', None)
+        self.namespace = kwargs.pop("namespace", None)
+        self.uid = kwargs.pop("uid", None)
+        self.access_token = kwargs.pop("access_token", None)
+        self.claims = kwargs.pop("claims", None)
         self.groups = self._groups_from_claims()
 
     def _groups_from_claims(self):
@@ -39,7 +39,7 @@ class User(object):
         imo = self.claims.get("isMemberOf")
         if not imo:
             return None
-        gnames = [x['name'] for x in imo if 'id' in x]
+        gnames = [x["name"] for x in imo if "id" in x]
         return gnames
 
     def dump(self):
@@ -49,14 +49,14 @@ class User(object):
             "namespace": self.namespace,
             "uid": self.uid,
             "groups": self.groups,
-            "access_token": "<REDACTED>"
+            "access_token": "<REDACTED>",
         }
         cc = {}
         if self.claims:
             cc.update(self.claims)
-        tok = cc.get('access_token', None)
+        tok = cc.get("access_token", None)
         if tok:
-            cc['access_token'] = "<REDACTED>"
+            cc["access_token"] = "<REDACTED>"
         rv["claims"] = cc
         return rv
 
